@@ -161,6 +161,7 @@ def test_timeline_with_re(mock_get, monkeypatch, capsys):
             'acct': 'fz'
         },
         'reblog': {
+            'created_at': '2017-04-12T15:53:18.174Z',
             'account': {
                 'display_name': 'Johnny Cash',
                 'acct': 'jc'
@@ -177,10 +178,10 @@ def test_timeline_with_re(mock_get, monkeypatch, capsys):
     mock_get.assert_called_once_with(app, user, '/api/v1/timelines/home', {'limit': 10})
 
     out, err = capsys.readouterr()
-    lines = out.split("\n")
+    lines = uncolorize(out).split("\n")
 
-    assert "Frank Zappa" in lines[1]
-    assert "@fz" in lines[1]
+    assert "Johnny Cash" in lines[1]
+    assert "@jc" in lines[1]
     assert "2017-04-12 15:53 UTC" in lines[1]
 
     assert (
@@ -188,7 +189,7 @@ def test_timeline_with_re(mock_get, monkeypatch, capsys):
         "exact mathematical design, but\nwhat's missing is the eyebrows." in out)
 
     assert "111111111111111111" in lines[-3]
-    assert "↻ Reblogged @jc" in lines[-3]
+    assert "↻ @fz boosted" in lines[-3]
 
     assert err == ""
 
@@ -349,6 +350,7 @@ def test_search(mock_get, capsys):
     })
 
     out, err = capsys.readouterr()
+    out = uncolorize(out)
     assert "Hashtags:\n#foo, #bar, #baz" in out
     assert "Accounts:" in out
     assert "@thequeen Freddy Mercury" in out
