@@ -1,29 +1,20 @@
-# -*- coding: utf-8 -*-
-
-import os
 import json
+import os
 
 from functools import wraps
-from os.path import dirname
+from os.path import dirname, join
 
-from toot import User, App
-from toot.config_legacy import load_legacy_config
+from toot import User, App, get_config_dir
 from toot.exceptions import ConsoleError
 from toot.output import print_out
 
 
+TOOT_CONFIG_FILE_NAME = "config.json"
+
+
 def get_config_file_path():
-    """Returns the path to toot config file
-
-    Attempts to locate config home dir from XDG_CONFIG_HOME env variable.
-    See: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html#variables
-    If not found, defaults to `~/.config`.
-    """
-    config_dir = os.getenv('XDG_CONFIG_HOME', '~/.config')
-    return os.path.expanduser(config_dir + '/toot/config.json')
-
-
-CONFIG_FILE = get_config_file_path()
+    """Returns the path to toot config file."""
+    return join(get_config_dir(), TOOT_CONFIG_FILE_NAME)
 
 
 def user_id(user):
@@ -31,20 +22,11 @@ def user_id(user):
 
 
 def make_config(path):
-    """Creates a config file.
-
-    Attempts to load data from legacy config files if they exist.
-    """
-    apps, user = load_legacy_config()
-
-    apps = {a.instance: a._asdict() for a in apps}
-    users = {user_id(user): user._asdict()} if user else {}
-    active_user = user_id(user) if user else None
-
+    """Creates an empty toot configuration file."""
     config = {
-        "apps": apps,
-        "users": users,
-        "active_user": active_user,
+        "apps": {},
+        "users": {},
+        "active_user": None,
     }
 
     print_out("Creating config file at <blue>{}</blue>".format(path))
@@ -52,21 +34,26 @@ def make_config(path):
     # Ensure dir exists
     os.makedirs(dirname(path), exist_ok=True)
 
-    with open(path, 'w') as f:
+    # Create file with 600 permissions since it contains secrets
+    fd = os.open(path, os.O_CREAT | os.O_WRONLY, 0o600)
+    with os.fdopen(fd, 'w') as f:
         json.dump(config, f, indent=True)
 
 
 def load_config():
-    if not os.path.exists(CONFIG_FILE):
-        make_config(CONFIG_FILE)
+    path = get_config_file_path()
 
-    with open(CONFIG_FILE) as f:
+    if not os.path.exists(path):
+        make_config(path)
+
+    with open(path) as f:
         return json.load(f)
 
 
 def save_config(config):
-    with open(CONFIG_FILE, 'w') as f:
-        return json.dump(config, f, indent=True)
+    path = get_config_file_path()
+    with open(path, "w") as f:
+        return json.dump(config, f, indent=True, sort_keys=True)
 
 
 def extract_user_app(config, user_id):
@@ -114,6 +101,11 @@ def load_user(user_id, throw=False):
         raise ConsoleError("User '{}' not found".format(user_id))
 
 
+def get_user_list():
+    config = load_config()
+    return config['users']
+
+
 def modify_config(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
